Welcome to m_Librarian’s documentation! — m_Librarian 0.1.2 documentation

# Welcome to m_Librarian’s documentation!

This hopefully will be a collection of programs to index LibRusEc and Flibusta libraries (zipfiles from torrents, actually) and show their contents with command-line, web interface and GUI.

Contents:

- Before you begin
  - Software
  - Library archives
  - Configuration file
  - Database
- Installation using pip
  - System-wide
  - User mode
  - Virtual envs
- Progress bar
- Installation from sources
- Command-line scripts
  - ml-initdb.py
  - ml-import.py
  - ml-search.py
  - ml-web.py
- News
  - Version 0.1.2 (2018-05-22)
  - Version 0.1.1 (2018-05-17)
  - Version 0.1.0 (2018-04-25)
  - Version 0.0.17 (2018-03-24)
  - Version 0.0.16 (2018-03-22)
  - Version 0.0.15 (2017-04-26)
  - Version 0.0.14 (2016-07-29)
  - Version 0.0.13 (2016-06-11)
  - Version 0.0.12 (2016-06-09)
  - Version 0.0.11 (2016-06-06)
  - Version 0.0.10 (2016-05-31)
  - Version 0.0.9 (2016-05-30)
  - Version 0.0.8 (2016-05-29)
  - Version 0.0.7 (2016-05-25)
  - Version 0.0.6 (2016-05-21)
  - Version 0.0.5 (2016-05-14)
  - Version 0.0.4 (2016-05-11)
  - Version 0.0.3 (2015-12-24)
  - Version 0.0.2 (2015-12-21)
  - Version 0.0.1 (2015-12-15)

# Indices and tables

- Index
- Module Index
- Search Page

# Credits

Created by Oleg Broytman <phd@phdru.name>.

Copyright (C) 2015-2018 PhiloSoft Design.

# License

GPL.